""" Discover
"""
from eea.rdfrepository.interfaces import IFeedDiscover, IFeedContent
from persistent.dict import PersistentDict
from persistent.list import PersistentList
from zope.annotation.interfaces import IAnnotations
from zope.schema.interfaces import IVocabularyFactory
from zope.component import adapts
from zope.interface import implements
from zope.schema.vocabulary import SimpleTerm, SimpleVocabulary

KEY = 'eea.rdfrepository.discover'

class DiscoverAdapter(object):
    """ Discover Adapter
    """
    implements(IFeedDiscover)
    adapts(IFeedContent)

    def __init__(self, context):
        self.context = context
        annotations = IAnnotations(context)
        mapping = annotations.get(KEY)
        if mapping is None:
            discover =  { 'search_attrs': PersistentList() }
            mapping = annotations[KEY] = PersistentDict(discover)
        self.mapping = mapping

    def gets(self):
        """ Get search attrs
        """
        anno = IAnnotations(self.context)
        mapping = anno.get(KEY)
        return list(mapping['search_attrs'])

    def sets(self, value):
        """ Set search attrs
        """
        anno = IAnnotations(self.context)
        mapping = anno.get(KEY)
        mapping['search_attrs'] = PersistentList(value)

    search_attrs = property(gets, sets)


class DiscoverAttributesVocabulary(object):
    """ Discover Attributes Vocabulary
    """
    implements(IVocabularyFactory)

    def __call__(self, context):
        terms = []
        terms.append(SimpleTerm('title', 'title', 'title'))
        terms.append(SimpleTerm('subject', 'subject', 'subject'))
        terms.append(SimpleTerm('description', 'description', 'description'))
        return SimpleVocabulary(terms)

DiscoverAttributesVocabularyFactory = DiscoverAttributesVocabulary()
