""" RDF Repository
"""
from eea.rdfrepository.interfaces import IRDFRepository
from eea.rdfrepository.interfaces import IRDFRepositoryPlugin
from zope.app.component.hooks import getSite
from zope.interface import implements
from zope.component import getAllUtilitiesRegisteredFor
from Products.CMFCore.utils import getToolByName

class RDFRepository(object):
    """ RDF Repository
    """
    implements(IRDFRepository)

    def getFeeds(self, types = None, search = None):
        """ Get feeds
        """
        if types == None:
            types = []
        if search == None:
            search = {}
        result = []
        plugins = self._getPlugins()
        for plugin in plugins:
            rdf = plugin.getFeeds(types = types, search = search)
            result.extend(rdf)

        return result

    def getPluginNames(self):
        """ Get plugin names
        """
        plugins = self._getPlugins()
        return [plugin.name for plugin in plugins]

    def getRepository(self):
        """ Gets the folder that contain rdf feeds
        """
        site = getSite()
        portal_catalog = getToolByName(site, 'portal_catalog')

        query = { 'object_provides':
                  'eea.rdfrepository.interfaces.IRDFRepository'}
        folder_brains = portal_catalog.searchResults(query)

        if not folder_brains:
            query['Language'] = 'all'
            folder_brains = portal_catalog.searchResults(query)

        if folder_brains:
            path = folder_brains[0].getPath()
            return path

        return None

    def _getPlugins(self):
        """ Get plugins
        """
        plugins = getAllUtilitiesRegisteredFor(IRDFRepositoryPlugin)
        return plugins
